@@ -9,7 +9,7 @@
 
 import os, logging, datetime
 import ctypes as ct
-from aug_sfutils import str_byt
+from aug_sfutils import str_byt, getlastshot, sfread
 
 logger = logging.getLogger('aug_sfutils.journal')
 
@@ -27,6 +27,21 @@ def getdict(struct):
     return dict((field, getattr(struct, field)) for field, _ in struct._fields_)
 
 
+def anyshot():
+
+    nshot = getlastshot.getlastshot()
+    date_fmt = '%d%b%Y'
+    today = datetime.datetime.now().strftime(date_fmt)
+    date_last = 'No date'
+    jou = sfread.SFREAD(nshot, 'JOU')
+    if jou.status:
+        date_last = jou.time.strftime(date_fmt)
+    logger.info('Today is %s', today) 
+    logger.info('Last shot %d on %s', nshot, date_last) 
+
+    return(today == date_last)
+
+
 class jouEntry(ct.Structure):
     """
     Class defining the ctypes structure for a full journal entry
