@@ -254,8 +254,8 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
         Bz = np.apply_along_axis(np.gradient, 0, -Psi)/eqm.Rmesh[:, None]
         fBt = interp1d(eqm.pfl[i], eqm.jpol[i], kind='linear', fill_value='extrapolate')
         Bt = fBt(Psi)*mu_0/eqm.Rmesh[:, None]
-        r = np.squeeze(r_in[jt])
-        z = np.squeeze(z_in[jt])
+        r = r_in[jt] #np.squeeze(r_in[jt])
+        z = z_in[jt] #np.squeeze(z_in[jt])
         f_br = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh, Br, kx=2, ky=2)
         f_bz = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh, Bz, kx=2, ky=2)
         f_bt = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh, Bt, kx=2, ky=2)
